<#********************************************************************
*
*  Name:            PowerShellExtensionsforWindowsExplorer.ps1 
*  Author:          Darwin Sanoy
*  Updates:         http://csi-windows.com/toolkit
*  Bug Reports &
*  Enhancement Req: http://CSI-Windows.com/about/contact-us
*
*  Built/Tested On: 64-bit Win7
*  Requires:        PowerShell 2 or later
*
*  COPYRIGHT NOTICE:  This script is Copyrighted by Synaptic Fireworks, LLC

*    If you received this script directly from CSI-Windows.com as a result
*    training, a conference or personal contact with staff, then you are 
*    allowed to use the script in your organization.
*
*    No public or private redistribution of this code is allowed.  This     
*    includes, but is not limited to, email, posting to websites, blogs 
*    or forums.
*
*    This copyright notice and all comments in the script must remain intact.
*
*  Version:         1.1
*
*  Revision History:
*    11/08/13 - 1.1 - inital version (djs)
*
*******************************************************************#>
$Banner = @"

        *************************************************************
        *                    CSI-Windows.com                        *
        *   Explorer Extensions for PowerShell Script Development   *
        *                                                           *
        *    1) Add "Console Here" Options on Folders               *
        *    2) Add Run Options on .PS1 Files (32/64,Admin,V2)      *
        *    3) Explorer Preview for .PS1 Files (see inside file)   *
        *                                                           *
        *************************************************************
"@

$Explanation = @"
  This adds options to .PS1 files and to Folders
  PS1 FILES:                     FOLDERS:
    *) Run in 32-bit                *) PSH Con Here 32-bit
    *) Run in 32-bit as Admin       *) PSH Con Here 32-bit as Admin
    *) Run in 64-bit                *) PSH Con Here 64-bit
    *) Run in 64-bit as Admin       *) PSH Con Here 64-bit as Admin
    *) Reconfigure Run Options      *) Reconfigure Run Options

PowerShell 2.0 testing is critical if many of your machines are on version 2.0
while your development workstation is on 3.0.  You can either set all the above
options to run as 2.0 OR you can have seperate 2.0 menu options - which will add
four additional options to each of the above (with "$CurrentVerDesc" appended to each).

"@
if ((${env:\ProgramFiles(x86)} -ne $null) -and ($env:processor_architecture -ne "AMD64")){
		&"$env:windir\sysnative\windowspowershell\v1.0\powershell.exe" -noprofile -ExecutionPolicy bypass -file $myinvocation.Mycommand.path
		exit $LastExitCode 
	}

	Function Console-Prompt{
  Param( [String[]]$choiceList, 
	[String]$Caption = "Please make a selection", 
	[String]$Message = "Choices are presented below", 
	[int]$default = 0 
) 
Function global:Exit-Config {
  Write-Host -ForeGround Red "`n`nThis script has been cancelled as you requested.`n"
  Write-Host -ForeGround Blue "`nMore cool tools at CSI-Windows.com !	`n`n"
  Exit
}

Function global:SetContentMenuRegKeys {
    [CmdletBinding()]
    Param (
    [Parameter(Mandatory=$true,Position=0)][string]$SubKeyName,  
    [Parameter(Mandatory=$true,Position=1)][string]$DescriptionName,  
    [Parameter(Mandatory=$true,Position=2)][string]$KeyData,  
    [Parameter(Mandatory=$false,Position=3)][switch]$HasLUAShield
    )
  New-Item -Path "HKCU:\Software\classes\$ProgID\Shell\$SubKeyName\command" -force | Out-Null
	New-ItemProperty -Path "HKCU:\Software\classes\$ProgID\Shell\$SubKeyName" -Name "`(Default`)" -Value $DescriptionName -PropertyType ExpandString -force | Out-Null
	If ($HasLUAShield) {New-ItemProperty -Path "HKCU:\Software\classes\$ProgID\Shell\$SubKeyName" -Name "HasLUAShield" -Value "" -PropertyType String -force | Out-Null}
	New-ItemProperty -Path "HKCU:\Software\classes\$ProgID\Shell\$SubKeyName\command" -Name "`(Default`)" -Value $KeyData -PropertyType ExpandString -force | Out-Null
}

$choicedesc = New-Object System.Collections.ObjectModel.Collection[System.Management.Automation.Host.ChoiceDescription] 
$choiceList | foreach { 
$comps = $_ -split '=' 
$choicedesc.Add((New-Object "System.Management.Automation.Host.ChoiceDescription" -ArgumentList $comps[0],$comps[1]))} 
#$choicedesc.Add((New-Object "System.Management.Automation.Host.ChoiceDescription" -ArgumentList $_))} 
$Host.ui.PromptForChoice($caption, $message, $choicedesc, $default) 
} 

$PSCurrentVersion = $psversiontable.psversion.major
$StdChoicesVerDesc = $CurrentVerDesc = " PSH v$PSCurrentVersion"
$VerDescSep = $Ver2Desc = " PSH v2"
$PSVersionSwitch = "-version 2.0"
$PSCurrentVersion = $psversiontable.psversion.major
$CallThisScript = @"
"%SystemRoot%\System32\WindowsPowerShell\v1.0\powershell.exe" $PowershellSwitches -file `"$($MyInvocation.MyCommand.Path)`"
"@

cls

Write-Host -foregroundcolor BLUE "$banner"
Write-Host "$Explanation"
$global:ProgID = (Get-ItemProperty -literalpath HKLM:\SOFTWARE\Classes\.ps1).'(default)'
#Default the Options
$PSVersionOption = $null
$NoProfile = "-NoProfile"
$NoExit = "-NoExit"
$ExecutionPolicy = "-ExecutionPolicy Bypass"
$NoLogo = "-NoLogo"
$StdChoicesVerDesc = $CurrentVerDesc
$VerDescSep = $Ver2Desc
$SeperateChoices = $true 

Switch (Console-Prompt -Caption "Reconfigure .PS1 Options" -Message "Do you wish to reconfigure .PS1 Right Click Options: " -choice "&Leave Them Alone =Leaves .PS1 Right Click Menu as it currently is.", "&Default Recommended Configuration for .PS1 Right Click Options=Change current setting to recommended defaults with no more questions.","&Configure Detailed .PS1 Right Click Options=Change current settings in detail.","&Remove .PS1 Right Click Options=Remove current settings.","&Exit Config=Exits this script" -default 0)
  {
	0 {$ConfigPS1 = $False} 
  1 {$RemovePS1 = $True
     $ConfigPS1 = $True
     $DefaultConfiguration = $True}
  2 {$RemovePS1 = $True
     $ConfigPS1 = $True} 
	3 {$RemovePS1 = $True} 
	4 {Exit-Config} 
  }

If ($RemovePS1) {
"  Cleaning Up PS1 ..."
Remove-Item -Path "HKCU:\Software\classes\$ProgID" -Recurse -Force -ErrorAction 'SilentlyContinue'
}

If ($ConfigPS1) {
#******************** .PS1 Configuration ************************

Write-Host -ForegroundColor Red "Configuring PS1 Script Execution Options"

If (!$DefaultConfiguration) {
Switch (Console-Prompt -Caption "Whether To Load PSH Profiles (-NoProfile)" -Message "When right clicking PS1s, do you want to: " -choice "&Disable PowerShell Profiles (Recommended) =Disabling profiles in production prevents your script from running unknown code.", "&Enable PowerShell Profiles =Runs unknown code and may cause you to deploy scripts that depend on things that are only in your personal PSH profile.","&Exit Config=Exits this script" -default 0)
  {
	0 {$NoProfile = "-NoProfile"} 
	1 {$NoProfile = $Null} 
	2 {Exit-Config} 
  }

Switch (Console-Prompt -Caption "Whether to Leave Prompt Open (-NoExit)" -Message "When right clicking PS1s, do you want to: " -choice "&Leave PowerShell Prompt Open After Script Executes (Recommended) =This is SUPER useful for debugging scripts when they fail.", "&Close PowerShell Prompt After Script Executes =Prompt closes immediately after execution.","&Exit Config=Exits this script" -default 0)
  {
	0 {$NoExit = "-NoExit"} 
	1 {$NoExit = $Null} 
	2 {Exit-Config} 
  }

Switch (Console-Prompt -Caption "Execution Policy (-ExecutionPolicy)" -Message "When right clicking PS1s, what do you want the execution policy to be (only affects right click execution - DOES NOT change your default policies.): " -choice "&Bypass (Recommended)=Bypass is the same as Unrestricted, EXCEPT you also do not get nagged about executing scripts from the network as admin.", "&Unrestricted=Allows any script to execute.", "Remote&Signed=Scripts on the network must be signed, but local ones do not need to be.", "&AllSigned=All scripts must be signed.","&Exit Config=Exits this script" -default 0)
{
	0 {$ExecutionPolicy = "-ExecutionPolicy Bypass"} 
	1 {$ExecutionPolicy = "-ExecutionPolicy Unrestricted"} 
	2 {$ExecutionPolicy = "-ExecutionPolicy RemoteSigned"} 
	3 {$ExecutionPolicy = "-ExecutionPolicy AllSigned"} 
	4 {$ExecutionPolicy = "-ExecutionPolicy Restricted"}
  5 {Exit-Config}
} 

If ($psversiontable.psversion.major -gt 2) {
Switch (Console-Prompt -Caption "Version of PowerShell" -Message "When right clicking PS1s, what version of PowerShell do you want to be used (testing on 2.0 is important if you have both 2.0 and later in production): " -choice "&Latest Installed=Whatever version of PowerShell is Installed", "2.0 In the &Standard Set of Right Click Choices=Standard set of right click choices executes 2.0 (2.0 choices are labelled)", "2.0 Using An &Additional Set of Right Click Choices=Right click choices are added for both the latest version and 2.0 (2.0 choices are labelled)","&Exit Config=Exits this script" -default 0 )
  {
  0 { $SeperateChoices = $False}
  1 { $PSVersionOption = $PSVersionSwitch
      $StdChoicesVerDesc = $Ver2Desc
      $SeperateChoices = $False
      }
  2 { 
      $VerDescSep = $Ver2Desc
      $SeperateChoices = $True
      }
  3 {Exit-Config}
  }
}
}

$PowershellSwitches = "$PSVersionOption $NoLogo $NoExit $NoProfile $ExecutionPolicy"
"Configuring with command line options: ""$PowershellSwitches"" ..."
$NextKeyData = $DefaultKeyData = @"
%systemroot%\System32\windowspowershell\v1.0\powershell.exe -windowstyle hidden -command "start-process -verb 'runas' -filepath `$env:SystemRoot\System32\WindowsPowerShell\v1.0\powershell.exe -argumentlist "" $PowershellSwitches -file """"""%1"""""" %*"""
"@
$NextKeyDataNonElevated = $DefaultKeyDataNonElevated = @"
"%SystemRoot%\System32\WindowsPowerShell\v1.0\powershell.exe" $PowershellSwitches -file "%1" %*
"@
#First to 32-bit As Admin, both platforms

If (!($psversiontable.psversion.major -gt 2)) { $SeperateChoices = $false}

"  Setting 32-bit .PS1 Options..."
#32-bit As Admin for 32 or 64-bit OS
if ((Test-Path env:ProgramFiles`(x86`)) -and (${env:\ProgramFiles(x86)})) {
	#32-bit options on 64-bit OS
	$NextKeyData = $DefaultKeyData.Replace("System32","SysWOW64")
	$NextKeyDataNonElevated = $DefaultKeyDataNonElevated.Replace("System32","SysWOW64")
}
      
SetContentMenuRegKeys "CSI_Run32-BitAsAdmin$StdChoicesVerDesc" "Run in 32-bit As Admin$StdChoicesVerDesc" "$NextKeyData" -HasLUAShield      
If ($SeperateChoices) {
  SetContentMenuRegKeys "CSI_Run32-BitAsAdmin$VerDescSep" "Run in 32-bit As Admin$VerDescSep" $($NextKeyData.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches")) -HasLUAShield
}
#32-bit Non Admin
SetContentMenuRegKeys "CSI_Run32-Bit$StdChoicesVerDesc" "Run in 32-bit$StdChoicesVerDesc" "$NextKeyDataNonElevated"
If ($SeperateChoices) {
  SetContentMenuRegKeys "CSI_Run32-Bit$VerDescSep" "Run in 32-bit$VerDescSep" $NextKeyDataNonElevated.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches")
}

#Reconfigure
#SetContentMenuRegKeys "CSI2_Reconfig" "Config PSH Explorer Options (CSI-Windows.com)" $DefaultKeyDataNonElevated.Replace("`"%1`" %*","`"$($MyInvocation.MyCommand.Path)`"")
SetContentMenuRegKeys "CSI2_Reconfig" "Config PSH Explorer Options (CSI-Windows.com)" $CallThisScript
#64-bit 
"  Setting 64-bit .PS1 Options..."
if ((Test-Path env:ProgramFiles`(x86`)) -and (${env:\ProgramFiles(x86)})) {
  #64-bit Admin
  SetContentMenuRegKeys "CSI_Run64-BitAsAdmin$StdChoicesVerDesc" "Run in 64-bit As Admin$StdChoicesVerDesc" "$DefaultKeyData" -HasLUAShield
	If ($SeperateChoices) {
    SetContentMenuRegKeys "CSI_Run64-BitAsAdmin$VerDescSep" "Run in 64-bit As Admin$VerDescSep" $DefaultKeyData.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches") -HasLUAShield
  }
  #64-bit NonAdmin
  SetContentMenuRegKeys "CSI_Run64-Bit$StdChoicesVerDesc" "Run in 64-bit$StdChoicesVerDesc" "$DefaultKeyDataNonElevated"
  If ($SeperateChoices) {
    SetContentMenuRegKeys "CSI_Run64-Bit$VerDescSep" "Run in 64-bit$VerDescSep" $DefaultKeyDataNonElevated.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches")
  }
}

"  .PS1 Configuration Complete."
"`n`nYou now have new options when you right click .PS1 files and folders."
}

#******************** Console Configuration ************************
$global:ProgID = "Directory"

#Default the Options
$VerDescSep = $null
$StdChoicesVerDesc = $null
$PSVersionOption = $null
$StdChoicesVerDesc = $CurrentVerDesc
$VerDescSep = $Ver2Desc
$ExecutionPolicy = "-ExecutionPolicy Bypass"
$NoProfile = "-NoProfile"
$NoExit = "-NoExit"
$NoLogo = "-NoLogo"
$SeperateChoices = $True

Switch (Console-Prompt -Caption "Reconfigure Console Options" -Message "Do you wish to reconfigure Folder Right Click Options for PSH Consoles: " -choice "&Leave Them Alone =Leaves current configuration as is.", "&Default Recommended Configuration=Change current setting to recommended defaults with no more questions.","&Configure Detailed Right Click Options=Change current settings in detail.","&Remove current configuration=Remove current settings.","&Exit Config=Exits this script" -default 0)
  {
	0 {$ConfigCON = $False} 
  1 {$RemoveCON = $True
     $ConfigCON = $True
     $SeperateChoices = $True
     $DefaultConfiguration = $True}
  2 {$RemoveCON = $True
     $ConfigCON = $True} 
	3 {$RemoveCON = $True} 
	4 {Exit-Config} 
  }

If ($RemoveCON) {
"  Cleaning Up Folder Menu ..."
Remove-Item -Path "HKCU:\Software\classes\$ProgID" -Recurse -Force -ErrorAction 'SilentlyContinue'
}

If ($ConfigCON) {
Write-Host -ForegroundColor Red "Configuring PSH Con Here Execution Options"
"  Cleaning Up Previous Consoles Entries..."
If (!$DefaultConfiguration) {
Switch (Console-Prompt -Caption "Whether To Load PSH Profiles (-NoProfile)" -Message "When right clicking folders to open a PSH Console, do you want to: " -choice "&Disable PowerShell Profiles (Recommended) =Disabling profiles in production prevents your script from running unknown code.", "&Enable PowerShell Profiles =Runs unknown code and may cause you to deploy scripts that depend on things that are only in your personal PSH profile.","&Exit Config=Exits this script" -default 0)
  {
	0 {$NoProfile = "-NoProfile"} 
	1 {$NoProfile = $Null} 
	2 {Exit-Config} 
  }

Switch (Console-Prompt -Caption "Execution Policy (-ExecutionPolicy)" -Message "When right clicking folders to open a PSH Console, what do you want the execution policy to be (only affects right click execution - DOES NOT change your default policies.): " -choice "&Bypass (Recommended)=Bypass is the same as Unrestricted, EXCEPT you also do not get nagged about executing scripts from the network as admin.", "&Unrestricted=Allows any script to execute.", "Remote&Signed=Scripts on the network must be signed, but local ones do not need to be.", "&AllSigned=All scripts must be signed.","&Exit Config=Exits this script" -default 0)
{
	0 {$ExecutionPolicy = "-ExecutionPolicy Bypass"} 
	1 {$ExecutionPolicy = "-ExecutionPolicy Unrestricted"} 
	2 {$ExecutionPolicy = "-ExecutionPolicy RemoteSigned"} 
	3 {$ExecutionPolicy = "-ExecutionPolicy AllSigned"} 
	4 {$ExecutionPolicy = "-ExecutionPolicy Restricted"}
  5 {Exit-Config}
} 


$SeperateChoices = $False
If ($psversiontable.psversion.major -gt 2) {
Switch (Console-Prompt -Caption "Version of PowerShell" -Message "When right clicking folders to open a PSH Console, what version of PowerShell do you want to be used (testing on 2.0 is important if you have both 2.0 and later in production): " -choice "&Latest Installed=Whatever version of PowerShell is Installed", "2.0 In the &Standard Set of Right Click Choices=Standard set of right click choices executes 2.0 (2.0 choices are labelled)", "2.0 Using An &Additional Set of Right Click Choices=Right click choices are added for both the latest version and 2.0 (2.0 choices are labelled)","&Exit Config=Exits this script" -default 0 )
  {
  0 { $SeperateChoices = $False}
  1 { $StdChoicesVerDesc = $Ver2Desc
      $PSVersionOption = $PSVersionSwitch
      $SeperateChoices = $False
      }
  2 { $VerDescSep = $Ver2Desc
      $SeperateChoices = $True
      }
  3 {Exit-Config}
  }
}
}

$PowershellSwitches = "$PSVersionOption $NoLogo $NoExit $NoProfile $ExecutionPolicy"
$NextKeyData = $CmdPromptDefaultElevated = @"
%systemroot%\System32\windowspowershell\v1.0\powershell.exe $PowershellSwitches -windowstyle hidden -command "start-process -verb 'runas' -filepath %SystemRoot%\System32\WindowsPowerShell\v1.0\powershell.exe -argumentlist "" $PowerShellSwitches -command "cd -Path '%L%'; ((Get-Host).UI.RawUI).WindowTitle +=  '  [32-bit]' " """
"@
$NextKeyDataNonElevated = $CmdPromptDefaultNONElevated = @"
%systemroot%\System32\windowspowershell\v1.0\powershell.exe $PowershellSwitches -noexit -command "cd -path '%L'; ((Get-Host).UI.RawUI).WindowTitle +=  '  [32-bit]' "
"@

"Setting 32-bit Console Options..."

If (!($psversiontable.psversion.major -gt 2)) { $SeperateChoices = $false}

if ((Test-Path env:ProgramFiles`(x86`)) -and (${env:\ProgramFiles(x86)})) {
  #32-bit
	$NextKeyData = $CmdPromptDefaultElevated.Replace("System32","SysWOW64")
	$NextKeyDataNonElevated = $CmdPromptDefaultNONElevated.Replace("System32","SysWOW64")
}

SetContentMenuRegKeys "CSI_PSHCon32-BitAsAdmin$StdChoicesVerDesc" "PSH Con Here 32-bit As Admin$StdChoicesVerDesc" "$NextKeyData" -HasLUAShield
If ($SeperateChoices) {
  SetContentMenuRegKeys "CSI_PSHCon32-BitAsAdmin$VerDescSep" "PSH Con Here 32-bit As Admin$VerDescSep" "$($NextKeyData.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches"))" -HasLUAShield
}
  
#32-bit Non Admin
SetContentMenuRegKeys "CSI_PSHCon32-Bit$StdChoicesVerDesc" "PSH Con Here 32-bit$StdChoicesVerDesc" "$NextKeyDataNonElevated"
If ($SeperateChoices) {
  SetContentMenuRegKeys "CSI_PSHCon32-Bit$VerDescSep" "PSH Con Here 32-bit$VerDescSep" "$($NextKeyDataNonElevated.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches"))"
}
  
#64-bit 
"Setting 64-bit Console Options..."
if ((Test-Path env:ProgramFiles`(x86`)) -and (${env:\ProgramFiles(x86)})) {
  #64-bit Admin
	SetContentMenuRegKeys "CSI_PSHCon64-BitAsAdmin$StdChoicesVerDesc" "PSH Con Here 64-bit As Admin$StdChoicesVerDesc" $CmdPromptDefaultElevated.Replace("[32-bit]","[64-bit]") -HasLUAShield
  If ($SeperateChoices) {
    $NextKeyDataElevated = $CmdPromptDefaultElevated.Replace("[32-bit]","[64-bit]")
    SetContentMenuRegKeys "CSI_PSHCon64-BitAsAdmin$VerDescSep" "PSH Con Here 64-bit As Admin$VerDescSep" "$($NextKeyDataElevated.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches"))" -HasLUAShield
  }
  #64-bit NonAdmin
	SetContentMenuRegKeys "CSI_PSHCon64-Bit$StdChoicesVerDesc" "PSH Con Here 64-bit$StdChoicesVerDesc" $CmdPromptDefaultNONElevated.Replace("[32-bit]","[64-bit]")
  If ($SeperateChoices) {
    $NextKeyDataNonElevated = $CmdPromptDefaultNONElevated.Replace("[32-bit]","[64-bit]")
    SetContentMenuRegKeys "CSI_PSHCon64-Bit$VerDescSep" "PSH Con Here 64-bit$VerDescSep" "$($NextKeyDataNonElevated.Replace("$PowerShellSwitches","$PSVersionSwitch $PowerShellSwitches"))"
  }
}

#Reconfig on folders
#SetContentMenuRegKeys "CSI2_ReconfigCon" "Config PSH Explorer Options (CSI-Windows.com)" $DefaultKeyDataNonElevated.Replace("`"%1`" %*","`"$($MyInvocation.MyCommand.Path)`"")
SetContentMenuRegKeys "CSI2_ReconfigCon" "Config PSH Explorer Options (CSI-Windows.com)" $CallThisScript
"  PSH Console Configuration Complete."
"`n`nYou now have new options for PowerShell Consoles when you right click folders."
}

#******************** Explorer Preview Pane Configuration ************************

Switch (Console-Prompt -Caption "Reconfigure Explorer .PS1 Preview Options" -Message "Do you wish to Reconfigure Explorer .PS1 Preview Options: " -choice "&Leave Them Alone =Leaves current configuration as is.", "&Default Recommended Configuration=Change current setting to recommended defaults with no more questions.","&Configure Detailed Options=Change current settings in detail.","&Remove current configuration=Remove current settings.","&Exit Config=Exits this script" -default 0)
  {
	0 {$ConfigPreview = $False
     $RemovePreview = $False} 
	1 {$ConfigPreview = $True
     $RemovePreview = $True} 
	2 {$ConfigPreview = $True
     $RemovePreview = $True} 
	3 {$ConfigPreview = $False
     $RemovePreview = $True} 
	4 {Exit-Config} 
  }

If ($RemovePreview) {
"  Cleaning Up Explorer Preview..."
  @(".ps1",".ps1xml",".psc1",".psm1") | % {Remove-Item -Force -Path "HKCU:\Software\Classes\$((Get-ItemProperty -literalpath HKLM:\SOFTWARE\Classes\$_).'(default)')\shellex\{8895b1c6-b41f-4c1c-a562-0d564250836f}" -ErrorAction 'SilentlyContinue' | Out-Null }
  @(".vbs",".cmd",".bat",".reg",".xml") | % {Remove-Item -Force -Path "HKCU:\Software\Classes\$((Get-ItemProperty -literalpath HKLM:\SOFTWARE\Classes\$_).'(default)')\shellex\{8895b1c6-b41f-4c1c-a562-0d564250836f}" -erroraction 'SilentlyContinue'  | Out-Null }
}

If ($ConfigPreview) {
  If (!$DefaultConfiguration) {
    $DontChangePSHPreviews = [boolean](Console-Prompt -Caption "Enable Explorer Preview of .PS1" -Message "Would you like explorer to show .PS1 code in the preview pane: " -choice "&Enable Previewing .PS1 Files in Explorer (Recommended)", "&Leave as is." -default 0)
    $DontChangeOtherPreviews = [boolean](Console-Prompt -Caption "Enable Explorer Preview of .VBS, .CMD, .BAT, .REG & .XML" -Message "Would you like explorer to show .VBS, .CMD, .BAT, .REG & .XML file contents in the preview pane: " -choice "&Enable Previewing .VBS, .CMD, .BAT, .REG & .XML Files in Explorer (Recommended)", "&Disable .VBS, .CMD, .BAT, .REG & .XML Previewing" -default 0)
  }

  If (!$DontChangePSHPreviews -or $DefaultConfiguration) {
    @(".ps1",".ps1xml",".psc1",".psd1",".psd1",".psm1") | % {New-Item -Force -Path "HKCU:\Software\Classes\$((Get-ItemProperty -literalpath HKLM:\SOFTWARE\Classes\$_).'(default)')\shellex\{8895b1c6-b41f-4c1c-a562-0d564250836f}" -Value "{1531d583-8375-4d3f-b5fb-d23bbd169f22}" | Out-Null }
  }

  If (!$DontChangeOtherPreviews -or $DefaultConfiguration) {
    @(".vbs",".cmd",".bat",".reg",".xml") | % {New-Item -Force -Path "HKCU:\Software\Classes\$((Get-ItemProperty -literalpath HKLM:\SOFTWARE\Classes\$_).'(default)')\shellex\{8895b1c6-b41f-4c1c-a562-0d564250836f}" -Value "{1531d583-8375-4d3f-b5fb-d23bbd169f22}"   | Out-Null }
  }
}

Write-Host -ForegroundColor Red "`nIf you install a new PS1 editor, you may need to rerun this script `n to restore your configuration."
Write-Host -ForeGround Blue "`nMore cool tools at CSI-Windows.com !	`n`n"